@@ -5,11 +5,12 @@ from functools import lru_cache
 from gtts import gTTS
 import subprocess
 import tempfile
+import time
 from practicejapanese.core.vocab import load_vocab
 from practicejapanese.core.utils import quiz_loop, update_score, lowest_score_items
 
 CSV_PATH = os.path.abspath(os.path.join(
-    os.path.dirname(__file__), "..", "data", "N5Vocab.csv"))
+    os.path.dirname(__file__), "..", "data", "Vocab.csv"))
 
 
 def play_tts(sentence):
@@ -17,17 +18,12 @@ def play_tts(sentence):
         tts = gTTS(text=sentence, lang='ja')
         with tempfile.NamedTemporaryFile(delete=False, suffix='.mp3') as fp:
             tts.save(fp.name)
-            # Detect Termux by checking for the environment variable
-            if 'com.termux' in os.environ.get('PREFIX', '') or os.environ.get('TERMUX_VERSION'):
-                # Use termux-media-player
-                subprocess.run(['termux-media-player', 'play', fp.name], check=True)
-            else:
-                # Use mpv for Linux
-                try:
-                    subprocess.run(['mpv', '--really-quiet', fp.name], check=True)
-                except Exception as e:
-                    print(f"[TTS Error] {e}")
-        os.remove(fp.name)
+            # Only use mpv for audio playback
+            try:
+                subprocess.run(['mpv', '--really-quiet', fp.name], check=True)
+            except Exception as e:
+                print(f"[TTS Error] {e}")
+            os.remove(fp.name)
     except Exception as e:
         print(f"[TTS Error] {e}")
 
@@ -36,14 +32,23 @@ def ask_question(vocab_list):
     word = random.choice(vocab_list)
     questions = generate_questions(word)
     if not questions:
-        print(f"Attempted to generate questions for: {word}")
-        print("No fill-in questions generated. Check API or vocab data.")
-        print()  # Add empty line before the question
-        print("Replace the highlighted hiragana with the correct kanji:")
-        play_tts("問題の漢字は")
-        play_tts(word[0])
-        play_tts("問題の漢字は")
-        play_tts(word[0])
+        print()
+        # Define variables before using them
+        kanji = word[0]
+        reading = word[1]
+        meaning = word[2]
+        play_tts(f"問題の漢字は{kanji}")
+        print(f"Meaning: {meaning}")
+        play_tts(f"読み方は{reading}")
+        play_tts(f"問題の漢字は{kanji}")
+        user_input = input("Your answer (kanji): ").strip()
+        correct = (user_input == kanji)
+        if correct:
+            print("Correct!")
+        else:
+            print(f"Wrong. Correct kanji: {kanji}")
+        update_score(CSV_PATH, kanji, correct, score_col=4)
+        print()
         return
     # Select two distinct questions for context
     if len(questions) >= 2:
@@ -54,12 +59,10 @@ def ask_question(vocab_list):
     print()  # Add empty line before the question
     print("Replace the highlighted hiragana with the correct kanji:")
     print("(The sentences will be played as audio)")
-    play_tts("問題の漢字は")
-    play_tts(kanji)
+    play_tts(f"問題の漢字は{kanji}")
     for idx, (sentence, answer) in enumerate(selected):
         play_tts(sentence)
-    play_tts("問題の漢字は")
-    play_tts(kanji)
+    play_tts(f"問題の漢字は{kanji}")
     # Use the first question's answer for checking
     answer = selected[0][1]
     user_input = input("Your answer (kanji): ").strip()
@@ -68,6 +71,7 @@ def ask_question(vocab_list):
         print("Correct!")
     else:
         print(f"Wrong. Correct kanji: {answer}")
+    # Score column is 'FillingScore' (index 4)
     update_score(CSV_PATH, answer, correct, score_col=4)
     print()
 
