@@ -6,7 +6,7 @@ from practicejapanese.core.vocab import load_vocab
 from practicejapanese.core.utils import quiz_loop, update_score, lowest_score_items
 
 CSV_PATH = os.path.abspath(os.path.join(
-    os.path.dirname(__file__), "..", "data", "N5Vocab.csv"))
+    os.path.dirname(__file__), "..", "data", "Vocab.csv"))
 
 
 def ask_question(vocab_list):
@@ -14,8 +14,20 @@ def ask_question(vocab_list):
     word = random.choice(vocab_list)
     questions = generate_questions(word)
     if not questions:
-        print(f"Attempted to generate questions for: {word}")
-        print("No fill-in questions generated. Check API or vocab data.")
+        # Show hiragana and meaning if no fill-in questions can be generated
+        reading = word[1]
+        meaning = word[2]
+        kanji = word[0]
+        print(f"Reading: {reading}")
+        print(f"Meaning: {meaning}")
+        user_input = input("Your answer (kanji): ").strip()
+        correct = (user_input == kanji)
+        if correct:
+            print("Correct!")
+        else:
+            print(f"Wrong. Correct kanji: {kanji}")
+        update_score(CSV_PATH, kanji, correct, score_col=4)
+        print()
         return
     # Select two distinct questions for context
     if len(questions) >= 2:
@@ -33,6 +45,7 @@ def ask_question(vocab_list):
         print("Correct!")
     else:
         print(f"Wrong. Correct kanji: {answer}")
+    # Score column is 'FillingScore' (index 4)
     update_score(CSV_PATH, answer, correct, score_col=4)
     print()
 
