@@ -4,7 +4,7 @@ import random
 import os
 
 
-CSV_PATH = os.path.abspath(os.path.join(os.path.dirname(__file__), "..", "data", "N5Kanji.csv"))
+CSV_PATH = os.path.abspath(os.path.join(os.path.dirname(__file__), "..", "data", "Kanji.csv"))
 
 def ask_question(kanji_list):
     item = random.choice(kanji_list)
@@ -17,6 +17,7 @@ def ask_question(kanji_list):
         print("Correct!")
     else:
         print(f"Incorrect. The correct Kanji is: {item[0]}")
+    # Score column is 'Score' (index 3)
     update_score(CSV_PATH, item[0], correct, score_col=3)
     print()  # Add empty line after the question
 
